<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":		$messaggio = "Modifiez ou supprimez la réservation"; break;
case "Prenotazione a nome di":  				$messaggio = "Réservation au nom de "; break;
case "nato il":  								$messaggio = "né"; break;
case "nata il":  								$messaggio = "née"; break;
case "e":  										$messaggio = "et"; break;
case "CAP":  									$messaggio = "Code postal"; break;
case "Telefono":  								$messaggio = "Téléphone"; break;
case "2º telefono":  							$messaggio = "2ème téléphone"; break;
case "3º telefono":  							$messaggio = "3ème téléphone"; break;
case "Modifica i dati del cliente":  			$messaggio = "Modifiez les données du client"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "La réservation est de l'an précédent, on pourra modifier seulement la date finale"; break;
case "settimane":  								$messaggio = "semaines"; break;
case "giorni":  								$messaggio = "jours"; break;
case "giorno":  				$messaggio = "day"; break;
case "dal":  									$messaggio = "de"; break;
case "al":  									$messaggio = "à"; break;
case "cambia in":  								$messaggio = "changez en"; break;
case "in":  									$messaggio = "en"; break;
case "Nº di piano":  							$messaggio = "Numéro de l'étage"; break;
case "e/o di casa":  							$messaggio = "et/ou de maisons"; break;
case "e/o di persone":  						$messaggio = "et/ou de personnes"; break;
case "Nº di persone":  							$messaggio = "Nombre de personnes"; break;
case "Commento":  								$messaggio = "Commentaire"; break;
case "Cancella il commento":  					$messaggio = "Supprimez le commentaire"; break;
case "Tipo di tariffa":  						$messaggio = "Type de tarif"; break;
case "tariffa":  								$messaggio = "tarif"; break;
case "Sconto":  								$messaggio = "Escompte"; break;
case "Caparra":  								$messaggio = "Accompte"; break;
case "resto":  									$messaggio = "reste"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Recalculez l'acompte sur la base du nouveau tarif"; break;
case "Costo aggiuntivo unico":  				$messaggio = "Surcoût simple"; break;
case "moltiplicato per":  						$messaggio = "multiplié pour"; break;
case "Costo aggiuntivo settimanale":  			$messaggio = "Surcoût hebdomadaire"; break;
case "Costo aggiuntivo giornaliero":  			$messaggio = "Surcoût journalier"; break;
case "per":  									$messaggio = "pour"; break;
case "settimane moltiplicato per":  			$messaggio = "semaines multipliés par"; break;
case "giorni moltiplicato per":  				$messaggio = "jours multipliés par"; break;
case "della tariffa moltiplicato per":  		$messaggio = "tarif multiplié par"; break;
case "Prenotazione confermata":  				$messaggio = "Réservation confirmée"; break;
case "Totale da pagare":  						$messaggio = "Total à payer"; break;
case "Pagato":  								$messaggio = "Payé"; break;
case "aggiungi":  								$messaggio = "ajoutez"; break;
case "pagato tutto":  							$messaggio = "tout est payé"; break;
case "caparra ":  								$messaggio = "acompte"; break;
case "Ancora da pagare":  						$messaggio = "Reste à payer"; break;
case "Nuovo costo aggiuntivo unico":  			$messaggio = "nouveau surcoût simple"; break;
case "di":  									$messaggio = "de"; break;
case "da moltiplicare per":  					$messaggio = "multipliez par"; break;
case "letto":  									$messaggio = "lit"; break;
case "straordinario":  							$messaggio = "extraordinaire"; break;
case "Nuovo costo aggiuntivo settimanale":		$messaggio = "Nouveau surcoût hebdomadaire"; break;
case "Nuovo costo aggiuntivo giornaliero": 	 	$messaggio = "Nouveau surcoût journalier"; break;
case "nº di settimane da applicare":  			$messaggio = "nombre de semaines à appliquer"; break;
case "nº di giorni da applicare":  				$messaggio = "nombre de jours à appliquer"; break;
case "non specificato":  						$messaggio = "non spécifié"; break;
case "Modifica la prenotazione":  				$messaggio = "Modifiez la réservation"; break;
case "Cancella la prenotazione":  				$messaggio = "Supprimez la réservation";; break;
case "Torna indietro":  						$messaggio = "Retournez"; break;
case "SI":  									$messaggio = "Oui"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "effacez également ce qui était payé"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  						$messaggio = "La réservation"; break;
case "era già stata cancellata":  				$messaggio = "a été déjà supprimée"; break;
case "Prenotazione":  							$messaggio = "Réservation"; break;
case "cancellata":  							$messaggio = "supprimez"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>Elle n'a pas été supprimée</b> parce qu'elle a été modifiée entre-temps"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":				$messaggio = "Etes vous certain de vouloir <b>supprimer</b> la réservation"; break;
case "La data iniziale verrà cambiata dal":  											$messaggio = "La date initiale sera changée par"; break;
case "al":  									$messaggio = "à"; break;
case "La data finale verrà cambiata dal":  		$messaggio = "La date finale sera changée par"; break;
case "della casa":  							$messaggio = "de la maison"; break;
case "con massimo numero di occupanti":  		$messaggio = "avec le nombre maximum d'occupants"; break;
case "a":  										$messaggio = "à"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "Le nombre de personnes sera changé par"; break;
case "persone":  								$messaggio = "personnes"; break;
case "è stata <b>cancellata</b>":  	$messaggio = "elle a été <b>supprimée</b>"; break;
case "La prenotazione dal":  					$messaggio = "La réservation de"; break;
case "a nome di":  								$messaggio = "au nom de Mr et Mme"; break;
case "La prenotazione verrà":  					$messaggio = "La réservation sera"; break;
case "mantenuta":  								$messaggio = "maintenue à gauche"; break;
case "spostata":  								$messaggio = "déplacée"; break;
case "La tariffa":  							$messaggio = "Le tarif"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "n'existe plus, changez le avant la mise à jour"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "Il n'a pas été encore <b>inséré</b> le prix du"; break;
case "per la settimana dal":  					$messaggio = "pour la semaine de"; break;
case "per il giorno dal":  						$messaggio = "pour le jour de"; break;
case "La tariffa verrà cambiata da":  			$messaggio = "Le tarif sera changé par"; break;
case "Il costo aggiuntivo":  					$messaggio = "Le surcoût suppémentaire"; break;
case "Il costo aggiuntivo unico":  				$messaggio = "L'unique surcoût"; break;
case "Il costo aggiuntivo settimanale":  		$messaggio = "Le surcoût hebdomadaire";; break;
case "Il costo aggiuntivo giornaliero":  		$messaggio = "Le surcoût quotidien"; break;
case "non può essere moltiplicato per":  		$messaggio = "ne peut pas être multiplié par"; break;
case "verrà moltiplicato per":  				$messaggio = "il sera multiplié par"; break;
case "prima era":  								$messaggio = "il était"; break;
case "Le settimane del costo aggiuntivo": 	 	$messaggio = "Les semaines du surcoût"; break;
case "I giorni del costo aggiuntivo":  			$messaggio = "Les jours du surcoût"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "ils <b>dépassent</b> la durée de la réservation"; break;
case "verranno cabiate da":  					$messaggio = "seront changées par"; break;
case "verranno cabiati da":  					$messaggio = "seront changés par"; break;
case "verranno cabiate":  						$messaggio = "seront changée"; break;
case "verranno cabiati":  						$messaggio = "seront changé"; break;
case "<b>non</b> verranno cambiate":	$messaggio = "seront <b>pas</b> changées"; break;
case "<b>non</b> verranno cambiati":	$messaggio = "seront <b>pas</b> changés"; break;
case "su":  									$messaggio = "sur"; break;
case "Il prezzo del costo aggiuntivo":  		$messaggio = "Le prix du surcôut"; break;
case "verrà tolto":  							$messaggio = "sera supprimé"; break;
case "verrà aggiunto":  						$messaggio = "sera ajouté"; break;
case "come letto aggiuntivo":  					$messaggio = "comme lit supplémentaire"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "Les semaines du nouveau surcoût"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "Les jours du nouveau surcoût"; break;
case "supera il costo totale senza sconto":  			$messaggio = "il dépasse le coût total sans escompte"; break;
case "Lo sconto verrà cambiato da":  					$messaggio = "L'escompte sera changé par"; break;
case "supera il costo totale":  						$messaggio = "il dépasse le coût total"; break;
case "La caparra verrà cambiata da":  					$messaggio = "L'acompte sera changé par"; break;
case "supera il nuovo costo totale":  					$messaggio = "il dépasse le nouveau coût total"; break;
case "I soldi pagati verranno cambiati da":  			$messaggio = "La somme payée sera changée en"; break;
case "verrà <b>confermata</b>":  				$messaggio = "elle sera <b>confirmée</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "La confirmation sera enlevée de la réservation"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "Le <b>commentaire</b> sera changé"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "Le <b>commentaire</b> sera supprimé"; break;
case "Continua":  										$messaggio = "Continuez"; break;
case "modificata":  									$messaggio = "modifier"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>n'a pas été modifié</b> parce que la table de réservations a changé entre-temps"; break;
case "verrà cambiato da":  								$messaggio = "sera changé par"; break;
case "con costo agg.":  								$messaggio = "avec le surcoût"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Il n'y a aucune période des règles 1 dans lesquelles il soit permis d'insérer des réservations par l'usager"; break;
case "Prenotazione non confermata":  					$messaggio = "Réservation non confirmée"; break;
case "Inserita dall'utente":  							$messaggio = "inséré par l'utilisateur"; break;
case "Si considererà l'utente":  						$messaggio = "Utilisateur"; break;
case "come colui che ha inserito la prenotazione":		$messaggio = "sera considéré en tant que celui qui a inséré la réservation"; break;
case "Non si possono inserire altri costi":  			$messaggio = "Vous ne pouvez pas insérer plus de coûts"; break;
case "in questo periodo, già":  						$messaggio = "dans cette période, déjà"; break;
case "presenti":  										$messaggio = "présents"; break;
case "Non si puo inserire il costo aggiuntivo":			$messaggio = "Le surcoût additionnel"; break;
case "in questo periodo":  								$messaggio = "ne peut pas être inséré dans cette période"; break;
case "Settimane":  										$messaggio = "Semaines"; break;
case "Giorni":  										$messaggio = "Jours"; break;
case "mostra":  										$messaggio = "montrez"; break;
case "nascondi":  										$messaggio = "cachez"; break;
case "numeri diversi":  								$messaggio = "nombres différents"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Vous ne pouvez pas insérer plus d'un surcoût avec le pourcentage sur le prix total par réservation"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":			$messaggio = "Choisissez les semaines à appliquer pour le surcoût"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":				$messaggio = "Choisissez les jours à appliquer pour le surcoût"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "le nombre de personnes doit être inséré pour le surcoût"; break;
case "Non si possono inserire altri costi":  			$messaggio = "Vous ne pouvez pas insérer plus de coûts"; break;
case "in questo periodo, già":  						$messaggio = "dans cette période, déjà"; break;
case "presenti":  										$messaggio = "présents"; break;
case "della tariffa":  									$messaggio = "du tarif"; break;
case "del totale":  									$messaggio = "du total"; break;
case "della caparra":  									$messaggio = "de l'acompte"; break;
case "del resto caparra":  								$messaggio = "du reste acompte"; break;
case "di base":  										$messaggio = "de base"; break;
case "registra entrata":  								$messaggio = "enregistrez entrée"; break;
case "cancella entrata":  								$messaggio = "supprimez entrée"; break;
case "registra uscita":  								$messaggio = "enregistrez sortie"; break;
case "cancella uscita":  								$messaggio = "supprimez sortie"; break;
case "Metodo pagamento caparra":  						$messaggio = "Méthode de paiement de l'acompte"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "La méthode de paiement de l'acompte sera changée à"; break;
case "Metodo di pagamento":  							$messaggio = "Méthode paiement"; break;
case "metodo di pagamento":  							$messaggio = "méthode de paiement"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normalement les réservations déjà commencées, qui ont fait des inscriptions, qui ont enregistré l'horaire d'entrée ne sont pas déplacés"; break;
case "Prova di nuovo":  								$messaggio = "Essayez encore"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "déplaçant également des réservations commencées ensuite"; break;
case "è incompatibile con la tariffa selezionata":		$messaggio = "est incompatible avec le prix choisi"; break;
case "Il titolare della prenotazione":  	$messaggio = "The occupant of reservation"; break;
case "Prenotazioni vicine":  			$messaggio = "Close reservations"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "tutte":  					$messaggio = "all"; break;
case "ln.":  					$messaggio = "ln."; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "Are you sure you want to <b>delete</b> reservations"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "The <div style=\"display: inline; color: red;\">dates</div> are <b>wrong</b>"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Data for the <b>extraordinary</b> extra cost are <div style=\"display: inline; color: red;\">wrong or lacking</div>"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">discount</div>"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">deposit</div>"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "The <div style=\"display: inline; color: red;\">deposit</div>"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">paid</div> amount"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "totale":  				$messaggio = "total"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out not registered, register check-in before"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "You can't change the assignment of a reservation that is <div style=\"display: inline; color: red;\">between two years</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "Modify in previous year"; break;
case "Orario entrata stimato":  		$messaggio = "Estimated check-in time"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "The estimated check-in time will be changed to"; break;
case "Codice prenotazione":  			$messaggio = "Reservation code"; break;
case "rigenera":  				$messaggio = "regenerate"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "It was not possible moving the reservation due to the checkin"; break;
case "Cambia cliente":  			$messaggio = "Change client"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "New titular of the reservation"; break;
case "cliente numero":  			$messaggio = "client number"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "The titular of reservations"; break;
case "Cliente non trovato":  			$messaggio = "Client not found"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "numero":  				$messaggio = "number"; break;
case "La prenotazione numero":  		$messaggio = "The reservation number"; break;
case "non esiste":  				$messaggio = "does not exist"; break;
case "Ospiti della prenotazione":  		$messaggio = "Reservation guests"; break;
case "Modifica gli ospiti":  			$messaggio = "Modify guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "scade":  					$messaggio = "expires"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "The reservation origin will be changed to"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "Modify or delete reservations"; break;
case "Modifica le prenotazioni":  		$messaggio = "Modify reservations"; break;
case "Cancella le prenotazioni":  		$messaggio = "Delete reservations"; break;
case "della prenotazione":  			$messaggio = "from reservation"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "Data inserimento":  			$messaggio = "Insertion date"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "pren.":  					$messaggio = "res."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Calculate again the commissions from the new rate"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Commissions will be changed from"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "The total price will change from"; break;
case "saldo di":  				$messaggio = "balance"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Other reservations from the same client in the same period"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "there are other reservations from the same client in the same period that have not been paid yet"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "The total balance of money paid will be"; break;
case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
case "di una persona":  			$messaggio = "of one person"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "cambia il commento":  			$messaggio = "change comment"; break;
case "Il commento":  				$messaggio = "Comment"; break;
case "verrà cambiato":  			$messaggio = "will be changed"; break;
case "per ":  					$messaggio = "for "; break;
case "Il numero di":  				$messaggio = "The number of"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>